### Name: pga
### Title: Variable Selection by Darwinian Evolution in Parallel Universes
### Aliases: pga-package
### Keywords: models multivariate multivariate optimize

### ** Examples

## simulate some data, needles in a haystack
set.seed(2007)
sigma <- 1
N <- 120
d <- 100                           # a large problem, 100 variables
truth <- c(15,30,45,60,75,90)      # only 6 are in the model
beta <- rep(0,d)
beta[truth] <- c(1,1,2,2,3,3)      # different signal-to-noise ratio
X <- matrix(rnorm(N*d), N, d)
y <- X %*% beta + sigma*rnorm(N)

## run PGA
rslt <- pga(y, X, N=15, B=25)

## make a movie
view.movie(rslt, truth=c(15,30,45,60,75,90), filename="myPGA")
 
## make bubble and order plots
par(mfrow=c(2,2))
view.bubble(rslt, truth=c(15,30,45,60,75,90), grid=TRUE, ylim=c(0,1))
view.order(rslt, grid=TRUE, ylim=c(0,1))
 
## get answer
get.pga.ans(rslt)
get.topfew(rslt, num=6)

## simulate 25 times (smaller, toy example) and 
## calculate how often PGA succeeds ...
sigma <- 1
N <- 50
d <- 10
truth <- c(2,5,8)
beta <- rep(0,d)
beta[truth] <- c(1,1,1)
rslt.hard <- rslt.soft <- matrix(0, 25, d)
for (i in 1:25) {
set.seed(i)
X <- matrix(rnorm(N*d), N, d)
y <- X %*% beta + sigma*rnorm(N)
rslt <- pga(y, X, N=6, B=25)
ans.hard<-get.pga.ans(rslt); print(ans.hard)
ans.soft<-get.topfew(rslt, num=3); print(ans.soft)
rslt.hard[i,ans.hard]<-1
rslt.soft[i,ans.soft]<-1
}
sim.rslt <- rbind(
summarize.PGAsim(rslt.hard, truth=c(2,5,8), name="PGAhard"),
summarize.PGAsim(rslt.soft, truth=c(2,5,8), name="PGAsoft"))
sim.rslt



